function [kGrid qGrid iGrid gGrid hGrid]=getMIT(param,chi,rPerm,initialK,terminalQ)
global alpha Delta pi

% Time grid
T=100;
tGrid=0:Delta:100;
N=length(tGrid);

% Initialize grids
kGrid = repmat(initialK',[1 N]);
mpkGrid = alpha*(sum(kGrid,1)).^(alpha-1)*(1-pi)^(1-alpha);
wGrid = (1-alpha)*(sum(kGrid,1)).^(alpha)*(1-pi)^(-alpha);
qGrid = repmat(terminalQ',[1 N]);
gGrid = repmat([0 0]',[1 N]);
iGrid = repmat([0 0]',[1 N]);
rGrid = repmat(rPerm,[1 N]);
hGrid = repmat(0,[1 N]);

% Initialize tolerance
tol=1e-4;
update=2*tol;
updateRule=0.1;

while abs(update)>tol
    kGridOld = kGrid;
    qGridOld = qGrid;
    iGridOld = iGrid;
    gGridOld = gGrid;
    hGridOld = hGrid;

    % Step 1: update Q,H backward given K
    qGrid(:,end)=terminalQ;
    mpkGrid = alpha*(sum(kGrid,1)).^(alpha-1)*(1-pi)^(1-alpha);
    wGrid = (1-alpha)*(sum(kGrid,1)).^(alpha)*(1-pi)^(-alpha);
    hGrid(end)=wGrid(end)/rPerm;
    for n=(N-1):(-1):1
       if chi<Inf
           g0 = param(1) + (1/chi)*(qGrid(1,n+1)-1);
           i0 = g0 + (chi/2)*(g0-param(1))^2;
           g1 = param(2) + (1/chi)*(qGrid(2,n+1)-1);
           i1 = g1 + (chi/2)*(g1-param(2))^2;
       else
           g0 = param(1);
           i0 = g0;
           g1 = param(2);
           i1 = g1;
       end
       mpk = mpkGrid(n);
       r = rGrid(n+1);
       w = wGrid(n);
       
       qGrid(1,n) = ( qGrid(1,n+1) + Delta*(mpk - i0 + param(3)*(param(4)*qGrid(2,n+1)-qGrid(1,n+1))) )/( 1+ Delta*(r-g0) );
       qGrid(2,n) = ( qGrid(2,n+1) + Delta*(mpk - i1) )/( 1+ Delta*(r-g1) );
       hGrid(n) = (1/( 1+ Delta*r))*(Delta*w + hGrid(n+1));
    end

    % Step 2: update K forward given Q
    kGrid(:,end)=initialK;
    for n=1:(N-1)
       if chi<Inf
           g0 = param(1) + (1/chi)*(qGrid(1,n+1)-1);
           i0 = g0 + (chi/2)*(g0-param(1))^2;
           g1 = param(2) + (1/chi)*(qGrid(2,n+1)-1);
           i1 = g1 + (chi/2)*(g1-param(2))^2;
       else
           g0 = param(1);
           i0 = g0;
           g1 = param(2);
           i1 = g1;
       end
       gGrid(:,n) = [g0 g1]';
       iGrid(:,n) = [i0 i1]';

       kGrid(1,n+1) = (1+Delta*(g0-param(3)-param(7)))*kGrid(1,n) + Delta*param(7)*param(6)*pi;
       kGrid(2,n+1) = (1+Delta*(g1-param(7)))*kGrid(2,n) + Delta*param(3)*param(4)*kGrid(1,n);
end
    if chi<Inf
        gGrid(1,N)= param(1) + (1/chi)*(qGrid(1,N)-1);
        gGrid(2,N)= param(2) + (1/chi)*(qGrid(2,N)-1);
    else
        gGrid(1,N) = param(1);
        gGrid(2,N) = param(2);
    end
        
    kGrid = updateRule*kGrid + (1-updateRule)*kGridOld;
    update = (sum(sum(abs(kGrid-kGridOld))) + sum(sum(abs(qGrid-qGridOld))) + sum(sum(abs(hGrid-hGridOld))))*Delta;
end

end