%% Set up environment %%
% MAKE SURE TO SET CURRENT DIRECTORY TO ../CODES/MATLAB %

clear
set(0,'DefaultTextInterpreter','latex')
set(0,'DefaultAxesTickLabelInterpreter','latex');
set(0,'DefaultLegendInterpreter', 'latex')
   
set(0,'DefaultTextFontSize', 20)
set(0,'DefaultAxesFontSize', 20)
set(0,'DefaultLineLineWidth',4)

blue_egb = [68 118 170]/255;
red_egb = [204 102 119]/255;
yellow_egb = [221 170 51]/255;
green_egb = [102 204 187]/255;

tic

%% Parameters %%
global alpha Delta pi

alpha = 1/3;
Delta = 0.1;
pi = 0.15;

%% Calibration %%
%tic

% Initial values
param_inelastic =    [0.3892   -0.0275    0.4289    0.5091    1.6790    9.7184    0.1069    0.0410    0.0464];
param_elastic1  =    [0.3805   -0.0289    0.4248    0.5187    1.6927    9.9453    0.1123    0.0410    0.0402  370.2032];
param_elastic2  =    [0.3701   -0.0309    0.4198    0.5297    1.7065   10.1885    0.1184    0.0412    0.0331  166.2520];
param_elastic3  =    [0.3582   -0.0335    0.4140    0.5423    1.7223   10.4357    0.1251    0.0417    0.0253   99.4588];
param_elastic4  =    [0.3161   -0.0561    0.4059    0.6432    2.3181   10.7104    0.1758    0.0368    0.0100   27.7303];

% The mapping between model parameters and elements of the param vector
% gbar0 = param(1);
% gbar1 = param(2);
% tau = param(3);
% psi = param(4);
% kappa = param(5);
% Kbar = param(6);
% eta = param(7);
% rhoL = param(8);
% rhoE = param(9);

% Optimizer options
paramLB = [0 -1 0 0 0 0 0 0.01 0.01];
paramUB = [1 1 1 10 10 100 1 0.15 0.15];
options = optimoptions('fmincon','Algorithm','sqp','MaxFunctionEvaluations', 1e5, 'MaxIterations', 1e5,'StepTolerance',1e-10);

% Calibration inelastic
loss_inelastic = @(param) getLoss(param,Inf,0);
[param_inelastic lossValue_inelastic] = fmincon(loss_inelastic,param_inelastic,[],[],[],[],paramLB,paramUB,[],options);
modelFit_inelastic = getLoss(param_inelastic,Inf,1);
param_inelastic;

% Calibration elastic
paramLB = [0 -1 0 0 0 0 0 0.01 0.01 5];
paramUB = [1 1 1 10 10 100 1 0.15 0.15 750];

loss_elastic1 = @(paramChi) getLossChi(paramChi,-0.005,0);
[param_elastic1 lossValue_elastic1] = fmincon(loss_elastic1,param_elastic1,[],[],[],[],paramLB,paramUB,[],options);
modelFit_elastic1 = getLossChi(param_elastic1,-0.005,1);
param_elastic1;

loss_elastic2 = @(paramChi) getLossChi(paramChi,-0.01,0);
[param_elastic2 lossValue_elastic2] = fmincon(loss_elastic2,param_elastic2,[],[],[],[],paramLB,paramUB,[],options);
modelFit_elastic2 = getLossChi(param_elastic2,-0.01,1);
param_elastic2;

loss_elastic3 = @(paramChi) getLossChi(paramChi,-0.015,0);
[param_elastic3 lossValue_elastic3] = fmincon(loss_elastic3,param_elastic3,[],[],[],[],paramLB,paramUB,[],options);
modelFit_elastic3 = getLossChi(param_elastic3,-0.015,1);
param_elastic3;

loss_elastic4 = @(paramChi) getLossChi(paramChi,-0.04,0);
[param_elastic4 lossValue_elastic4] = fmincon(loss_elastic4,param_elastic4,[],[],[],[],paramLB,paramUB,[],options);
modelFit_elastic4 = getLossChi(param_elastic4,-0.04,1);
param_elastic4;

%disp('Calibration: done')
%toc

%% Baseline steady-state model solution %%
%tic
r = 0.06;
param = param_inelastic;
chi = Inf;

[Q0 Q1 Q g0 g1 D0 D1 D i0 i1 levQ0 levQ1 levD0 levD1 epy0 epy1 speed0 speed1 K0 K1 K MPK MPKnet theta kappaLevM0 W WE WE0 WL DE DM DD]=getSS(param,chi,r);
w0 = param(6)*(levQ0/(1+param(5)))/WE;
mu0=epy0+g0-param(9);
mu1=epy1+g1-param(9);
Jm = 1+(r-epy0-g0)/param(3);
Jm =(1+(1+param(5))*(param(4)*Q1-1))/(1+(1+param(5))*(Q0-1));
[eigenvec Gw zeta pdf pdf0 pdf1 cdf aggw top1share top01share top001share thetaProxy01 thetaProxy001] = getDistSS(param,mu0,mu1,w0,Jm);
Nw=length(Gw);

suffStat = -(epy0*levD0-param(5)/levQ0)/(epy0+g0-param(9));

%disp('Solve steady-state: done')
%toc

%% Solve baseline model experiment %%
%tic

[Q0_a Q1_a Q_a g0_a g1_a D0_a D1_a D_a i0_a i1_a levQ0_a levQ1_a levD0_a levD1_a epy0_a epy1_a speed0_a speed1_a K0_a K1_a K_a MPK_a MPKnet_a theta_a kappaLevM0_a W_a WE_a WE0_a WL_a DE_a DM_a DD_a]=getSS(param,chi,0.07);
w0_a = param(6)*(levQ0_a/(1+param(5)))/WE_a;
mu0_a=epy0_a+g0_a-param(9);
mu1_a=epy1_a+g1_a-param(9);
Jm_a =(1+(1+param(5))*(param(4)*Q1_a-1))/(1+(1+param(5))*(Q0_a-1));
[eigenvec_a Gw_a zeta_a pdf_a pdf0_a pdf1_a cdf_a aggw_a top1share_a top01share_a top001share_a thetaProxy01_a thetaProxy001_a top1thresh_a top01thresh_a top001thresh_a top0001thresh_a] = getDistSS(param,mu0_a,mu1_a,w0_a,Jm_a);

[Q0_b Q1_b Q_b g0_b g1_b D0_b D1_b D_b i0_b i1_b levQ0_b levQ1_b levD0_b levD1_b epy0_b epy1_b speed0_b speed1_b K0_b K1_b K_b MPK_b MPKnet_b theta_b kappaLevM0_b W_b WE_b WE0_b WL_b DE_b DM_b DD_b]=getSS(param,chi,0.05);
w0_b = param(6)*(levQ0_b/(1+param(5)))/WE_b;
mu0_b=epy0_b+g0_b-param(9);
mu1_b=epy1_b+g1_b-param(9);
Jm_b =(1+(1+param(5))*(param(4)*Q1_b-1))/(1+(1+param(5))*(Q0_b-1));
[eigenvec_b Gw_b zeta_b pdf_b pdf0_b pdf1_b cdf_b aggw_b top1share_b top01share_b top001share_b thetaProxy01_b thetaProxy001_b top1thresh_b top01thresh_b top001thresh_b top0001thresh_b] = getDistSS(param,mu0_b,mu1_b,w0_b,Jm_b);

tGrid=0:Delta:100;
rGrid = [0.07*tGrid(tGrid<10).^0 0.05*(1-exp(-0.075*(tGrid(tGrid>=10)-10))) + 0.07*exp(-0.075*(tGrid(tGrid>=10)-10))];

[tGrid rGrid RGrid mpkNetGrid aggKGrid aggQGrid top1 top01 top001 top0001 thetaProxy01Grid thetaProxy001Grid thetaProxy0001Grid totalGrid withinGrid betweenGrid top01shareBook]=getModelOutput(param_inelastic,Inf,rGrid);

%toc
%disp('Solve baseline model experiment: done')


%% Solve model steady-state (domestic savings glut) %%
%tic

[Q0Temp Q1Temp QTemp g0Temp g1Temp D0Temp D1Temp DTemp i0Temp i1Temp levQ0Temp levQ1Temp levD0Temp levD1Temp epy0Temp epy1Temp speed0Temp speed1Temp K0Temp K1Temp KTemp MPKTemp MPKnetTemp thetaTemp kappaLevM0Temp WTemp WETemp WE0Temp WLTemp DETemp DMTemp DDTemp]=getSS([ param(1:7) param(8:9)],chi,0.06);
SfTarget = WLTemp + WETemp - WTemp;

error=1; drhoBeg=0;
while error>1e-12
    [Q0Temp Q1Temp QTemp g0Temp g1Temp D0Temp D1Temp DTemp i0Temp i1Temp levQ0Temp levQ1Temp levD0Temp levD1Temp epy0Temp epy1Temp speed0Temp speed1Temp K0Temp K1Temp KTemp MPKTemp MPKnetTemp thetaTemp kappaLevM0Temp WTemp WETemp WE0Temp WLTemp DETemp DMTemp DDTemp]=getSS([ param(1:7) param(8:9) + drhoBeg ],chi,rGrid(1));
    residual = WLTemp + WETemp - WTemp - SfTarget;
    drhoBeg = drhoBeg + 0.001*residual;
    error=abs(residual);
end
thetaBeg = thetaTemp;
entrepShareBeg = WETemp/(WETemp + WLTemp);

error=1; drhoEnd=0;
while error>1e-12
    [Q0Temp Q1Temp QTemp g0Temp g1Temp D0Temp D1Temp DTemp i0Temp i1Temp levQ0Temp levQ1Temp levD0Temp levD1Temp epy0Temp epy1Temp speed0Temp speed1Temp K0Temp K1Temp KTemp MPKTemp MPKnetTemp thetaTemp kappaLevM0Temp WTemp WETemp WE0Temp WLTemp DETemp DMTemp DDTemp]=getSS([ param(1:7) param(8:9) + drhoEnd ],chi,rGrid(end));
    residual = WLTemp + WETemp - WTemp - SfTarget;
    drhoEnd = drhoEnd + 0.001*residual;
    error=abs(residual);
end
thetaEnd = thetaTemp;
entrepShareEnd = WETemp/(WETemp + WLTemp);

[Q0_a Q1_a Q_a g0_a g1_a D0_a D1_a D_a i0_a i1_a levQ0_a levQ1_a levD0_a levD1_a epy0_a epy1_a speed0_a speed1_a K0_a K1_a K_a MPK_a MPKnet_a theta_a kappaLevM0_a W_a WE_a WE0_a WL_a DE_a DM_a DD_a]=getSS(param_inelastic,Inf,0.07);
[Q0_b Q1_b Q_b g0_b g1_b D0_b D1_b D_b i0_b i1_b levQ0_b levQ1_b levD0_b levD1_b epy0_b epy1_b speed0_b speed1_b K0_b K1_b K_b MPK_b MPKnet_b theta_b kappaLevM0_b W_b WE_b WE0_b WL_b DE_b DM_b DD_b]=getSS(param_inelastic,Inf,0.05);

tableDomestiSG =[ rGrid(end)-rGrid(1) 0 log(theta_b/theta_a) ; 
                 rGrid(end)-rGrid(1) drhoEnd-drhoBeg log(thetaEnd/thetaBeg) ];

%toc
%disp('Solve model steady-state (domestic savings glut): done')

%% Revaluation gain decomposition %%
%tic

[Q0 Q1 Q g0 g1 D0 D1 D i0 i1 levQ0 levQ1 levD0 levD1 epy0 epy1 speed0 speed1 K0 K1 K MPK MPKnet theta kappaLevM0 W WE WE0 WL DE DM DD]=getSS(param_inelastic,Inf,0.07);
w0 = param(6)*(levQ0/(1+param(5)))/WE;
mu0=epy0+g0-param(9);
mu1=epy1+g1-param(9);
Jm =(1+(1+param(5))*(param(4)*Q1-1))/(1+(1+param(5))*(Q0-1));
[eigenvec Gw zeta pdf pdf0 pdf1 cdf aggw top1share top01share top001share thetaProxy01 thetaProxy001 top1thresh top01thresh top001thresh top0001thresh growth_top1 growth_top01 growth_top001 growth_top0001] = getDistSS(param,mu0,mu1,w0,Jm);
q_top_rel_pre_top1 = [levQ0 levQ1]*[growth_top1 1-growth_top1]'/Q;
q_top_rel_pre_top01 = [levQ0 levQ1]*[growth_top01 1-growth_top01]'/Q;
q_top_rel_pre_top001 = [levQ0 levQ1]*[growth_top001 1-growth_top001]'/Q;
q_top_rel_pre_top0001 = [levQ0 levQ1]*[growth_top0001 1-growth_top0001]'/Q;
top1_pre = top1(1);
top01_pre = top01(1);
top001_pre = top001(1);
top0001_pre = top0001(1);
top1_book_pre = top1(1)/q_top_rel_pre_top1;
top01_book_pre = top01(1)/q_top_rel_pre_top01;
top001_book_pre = top001(1)/q_top_rel_pre_top001;
top0001_book_pre = top0001(1)/q_top_rel_pre_top0001;

[Q0 Q1 Q g0 g1 D0 D1 D i0 i1 levQ0 levQ1 levD0 levD1 epy0 epy1 speed0 speed1 K0 K1 K MPK MPKnet theta kappaLevM0 W WE WE0 WL DE DM DD]=getSS(param_inelastic,Inf,0.05);
w0 = param(6)*(levQ0/(1+param(5)))/WE;
mu0=epy0+g0-param(9);
mu1=epy1+g1-param(9);
Jm =(1+(1+param(5))*(param(4)*Q1-1))/(1+(1+param(5))*(Q0-1));
[eigenvec Gw zeta pdf pdf0 pdf1 cdf aggw top1share top01share top001share thetaProxy01 thetaProxy001 top1thresh top01thresh top001thresh top0001thresh  growth_top1 growth_top01 growth_top001 growth_top0001] = getDistSS(param,mu0,mu1,w0,Jm);
q_top_rel_post_top1 = [levQ0 levQ1]*[growth_top1 1-growth_top1]'/Q;
q_top_rel_post_top01 = [levQ0 levQ1]*[growth_top01 1-growth_top01]'/Q;
q_top_rel_post_top001 = [levQ0 levQ1]*[growth_top001 1-growth_top001]'/Q;
q_top_rel_post_top0001 = [levQ0 levQ1]*[growth_top0001 1-growth_top0001]'/Q;
top1_post = top1(end-1);
top01_post = top01(end-1);
top001_post = top001(end-1);
top0001_post = top0001(end-1);
top1_book_post = top1(end-1)/q_top_rel_post_top1;
top01_book_post = top01(end-1)/q_top_rel_post_top01;
top001_book_post = top001(end-1)/q_top_rel_post_top001;
top0001_book_post = top0001(end-1)/q_top_rel_post_top0001;

table_reval = [ log(top1_post/top1_pre) log(top1_book_post/top1_book_pre) log(top1_post/top1_pre)-log(top1_book_post/top1_book_pre) ; 
  log(top01_post/top01_pre) log(top01_book_post/top01_book_pre) log(top01_post/top01_pre)-log(top01_book_post/top01_book_pre) ;  
  log(top001_post/top001_pre) log(top001_book_post/top001_book_pre) log(top001_post/top001_pre)-log(top001_book_post/top001_book_pre) ; 
  log(top0001_post/top0001_pre) log(top0001_book_post/top0001_book_pre) log(top0001_post/top0001_pre)-log(top0001_book_post/top0001_book_pre)];
%csvwrite('C:\Users\Emilien\Dropbox\2019_qTheory\save\table_reval.csv',table_reval)

%toc
%disp('Compute revaluation gain decomposition: done')

%% Capital elasticity %%
%tic

[Q0_a Q1_a Q_a g0_a g1_a D0_a D1_a D_a i0_a i1_a levQ0_a levQ1_a levD0_a levD1_a epy0_a epy1_a speed0_a speed1_a K0_a K1_a K_a MPK_a MPKnet_a theta_a kappaLevM0_a W_a WE_a WE0_a WL_a DE_a DM_a DD_a]=getSS(param_inelastic,Inf,0.07);
[Q0_b Q1_b Q_b g0_b g1_b D0_b D1_b D_b i0_b i1_b levQ0_b levQ1_b levD0_b levD1_b epy0_b epy1_b speed0_b speed1_b K0_b K1_b K_b MPK_b MPKnet_b theta_b kappaLevM0_b W_b WE_b WE0_b WL_b DE_b DM_b DD_b]=getSS(param_inelastic,Inf,0.05);
dilution_inelastic = [epy0_a epy0_b];
row_inelastic=[-2 0 0 0 0 log(theta_b/theta_a) 0];

[Q0_a Q1_a Q_a g0_a g1_a D0_a D1_a D_a i0_a i1_a levQ0_a levQ1_a levD0_a levD1_a epy0_a epy1_a speed0_a speed1_a K0_a K1_a K_a MPK_a MPKnet_a theta_a kappaLevM0_a W_a WE_a WE0_a WL_a DE_a DM_a DD_a]=getSS(param_elastic1(1:end-1),param_elastic1(end),0.07);
[Q0_b Q1_b Q_b g0_b g1_b D0_b D1_b D_b i0_b i1_b levQ0_b levQ1_b levD0_b levD1_b epy0_b epy1_b speed0_b speed1_b K0_b K1_b K_b MPK_b MPKnet_b theta_b kappaLevM0_b W_b WE_b WE0_b WL_b DE_b DM_b DD_b]=getSS(param_elastic1(1:end-1),param_elastic1(end),0.05);
dilution_elastic1 = [epy0_a epy0_b];
row_elastic1=[-2 -0.5 100*(MPK_b-MPK_a)*(-0.005)/(MPKnet_b-MPKnet_a) 100*((MPKnet_b-MPKnet_a)-(MPK_b-MPK_a))*(-0.005)/(MPKnet_b-MPKnet_a) -(log(K_b/K_a))/0.02 log(theta_b/theta_a) 1/param_elastic1(end)];

[Q0_a Q1_a Q_a g0_a g1_a D0_a D1_a D_a i0_a i1_a levQ0_a levQ1_a levD0_a levD1_a epy0_a epy1_a speed0_a speed1_a K0_a K1_a K_a MPK_a MPKnet_a theta_a kappaLevM0_a W_a WE_a WE0_a WL_a DE_a DM_a DD_a]=getSS(param_elastic2(1:end-1),param_elastic2(end),0.07);
[Q0_b Q1_b Q_b g0_b g1_b D0_b D1_b D_b i0_b i1_b levQ0_b levQ1_b levD0_b levD1_b epy0_b epy1_b speed0_b speed1_b K0_b K1_b K_b MPK_b MPKnet_b theta_b kappaLevM0_b W_b WE_b WE0_b WL_b DE_b DM_b DD_b]=getSS(param_elastic2(1:end-1),param_elastic2(end),0.05);
dilution_elastic2 = [epy0_a epy0_b];
row_elastic2=[-2 -1 100*(MPK_b-MPK_a)*(-0.01)/(MPKnet_b-MPKnet_a) 100*((MPKnet_b-MPKnet_a)-(MPK_b-MPK_a))*(-0.01)/(MPKnet_b-MPKnet_a) -(log(K_b/K_a))/0.02 log(theta_b/theta_a) 1/param_elastic2(end)];

[Q0_a Q1_a Q_a g0_a g1_a D0_a D1_a D_a i0_a i1_a levQ0_a levQ1_a levD0_a levD1_a epy0_a epy1_a speed0_a speed1_a K0_a K1_a K_a MPK_a MPKnet_a theta_a kappaLevM0_a W_a WE_a WE0_a WL_a DE_a DM_a DD_a]=getSS(param_elastic3(1:end-1),param_elastic3(end),0.07);
[Q0_b Q1_b Q_b g0_b g1_b D0_b D1_b D_b i0_b i1_b levQ0_b levQ1_b levD0_b levD1_b epy0_b epy1_b speed0_b speed1_b K0_b K1_b K_b MPK_b MPKnet_b theta_b kappaLevM0_b W_b WE_b WE0_b WL_b DE_b DM_b DD_b]=getSS(param_elastic3(1:end-1),param_elastic3(end),0.05);
dilution_elastic3 = [epy0_a epy0_b];
row_elastic3=[-2 -1.5 100*(MPK_b-MPK_a)*(-0.015)/(MPKnet_b-MPKnet_a) 100*((MPKnet_b-MPKnet_a)-(MPK_b-MPK_a))*(-0.015)/(MPKnet_b-MPKnet_a) -(log(K_b/K_a))/0.02 log(theta_b/theta_a) 1/param_elastic3(end)];

[Q0_a Q1_a Q_a g0_a g1_a D0_a D1_a D_a i0_a i1_a levQ0_a levQ1_a levD0_a levD1_a epy0_a epy1_a speed0_a speed1_a K0_a K1_a K_a MPK_a MPKnet_a theta_a kappaLevM0_a W_a WE_a WE0_a WL_a DE_a DM_a DD_a]=getSS(param_elastic4(1:end-1),param_elastic4(end),0.07);
[Q0_b Q1_b Q_b g0_b g1_b D0_b D1_b D_b i0_b i1_b levQ0_b levQ1_b levD0_b levD1_b epy0_b epy1_b speed0_b speed1_b K0_b K1_b K_b MPK_b MPKnet_b theta_b kappaLevM0_b W_b WE_b WE0_b WL_b DE_b DM_b DD_b]=getSS(param_elastic4(1:end-1),param_elastic4(end),0.05);
dilution_elastic4 = [epy0_a epy0_b];
row_elastic4=[-2 -4 100*(MPK_b-MPK_a)*(-0.04)/(MPKnet_b-MPKnet_a) 100*((MPKnet_b-MPKnet_a)-(MPK_b-MPK_a))*(-0.04)/(MPKnet_b-MPKnet_a) -(log(K_b/K_a))/0.02 log(theta_b/theta_a) 1/param_elastic4(end)];

row_ngm = [-2 -2 -2 0  (log(0.07/0.05)/(alpha-1)) NaN Inf ];
tableElasticMain = [ row_inelastic([1 2 6]) ; row_elastic1([1 2 6]) ; row_elastic2([1 2 6]) ; row_elastic3([1 2 6]) ; row_ngm([1 2 6]) ];
tableElasticAppendix = [ row_inelastic ; row_elastic1 ; row_elastic2 ; row_elastic3 ; row_elastic4 ];

%toc
%disp('Compute capital elasticity extension: done')

%% Compute total runtime of code
disp('TOTAL RUNTIME:')
toc
