
%% Generate tables %%
% MAKE SURE TO SET CURRENT DIRECTORY TO ../REPLICATION/OUTPUT %

% Table IV - targeted moments
table4=round(modelFit_inelastic',2,'significant')
table4_lbl={'Equity payout yield','Growth rate of wealth','Market leverage','Duration','Return on capital','Depreciation rate','Pareto inequality','Aggregate duration','NFA to domestic wealth'}

fid = fopen('./Tables/TableIV.tex','w')
    fprintf(fid, "Conditional micro moments & & & \\\\ \n")
    for i=1:4
        fprintf(fid, '$\\quad$  %s 1985-2015 & %.3g & %.3g \\\\ \n', table4_lbl(i)+" &" ,table4(i,1), table4(i,2))
    end
    fprintf(fid,"Macro moments & & & \\\\ \n")
    fprintf(fid, '$\\quad$  %s 1985 & %.3g & %.3g \\\\ \n ', table4_lbl(5)+" &" ,table4(5,1), table4(5,2))
    for i=6:8
        fprintf(fid, '$\\quad$  %s 1985-2015 & %.3g & %.3g \\\\ \n', table4_lbl(i)+" &" ,table4(i,1), table4(i,2))
    end
    fprintf(fid, '$\\quad$  %s 1985-2015 & %.3g & %.3g  \\\\', table4_lbl(9)+" &" ,table4(9,1), table4(9,2))
fclose(fid)

table4_fn = round(param_inelastic,3);
fid = fopen('./Tables/TableIV_fn.tex','w')
    fprintf(fid,'$(\\underline{g}_0,\\underline{g}_1,\\tau,\\psi,\\lambda,\\overline{K},\\eta,\\rho_L,\\rho_E)=$')
    fprintf(fid,'(%8.3f ,', table4_fn(1))
    fprintf(fid,'%8.3f ,', table4_fn(2:8))
    fprintf(fid,'%8.3f )', table4_fn(9))
fclose(fid)


% Table V - model experiment with domestic savings glut
table5 = round([tableElasticMain(:,1:2) 100*tableElasticMain(:,3)],2,'significant');
fid = fopen('./Tables/TableV.tex','w')
    fprintf(fid,'Baseline & %8.1f & %8.1f & %.3g \\\\ \n', table5(1,:))
    fprintf(fid,'Low-elasticity & %8.1f & %8.1f & %.3g \\\\ \n', table5(2,:))
    fprintf(fid,'Medium-elasticity & %8.1f & %8.1f & %.3g \\\\ \n', table5(3,:))
    fprintf(fid,'High-elasticity & %8.1f & %8.1f & %.3g \\\\ \n', table5(4,:))
    fprintf(fid,'Neoclassical growth model & %8.1f & %8.1f  & $-$ \\\\ ', table5(5,1:end-1))
fclose(fid)

% Table D1 - model experiment with domestic savings glut
tableD1 = round(tableDomestiSG*100,2,'significant');

fid = fopen('./Tables/TableDI.tex','w')
    fprintf(fid,'Baseline & %8.1f & %8.1f & %.3g \\\\ \n', tableD1(1,:))
    fprintf(fid,'Domestic savings glut & %8.1f & %8.1f & %.3g   \\\\ ', tableD1(2,:))
fclose(fid)

% Table D2 - targeted moments (elastic capital calibrations)
tableD2 = round(round([[ modelFit_inelastic(2,:)' ; 0] modelFit_elastic1(1,:)'  modelFit_elastic2(1,:)'  modelFit_elastic3(1,:)'],2,'significant'),3)

fid = fopen('./Tables/TableDII.tex','w')
    fprintf(fid, "Conditional micro moments & & & & & \\\\ \n")
    for i=1:4
        fprintf(fid, '$\\quad$   %s 1985-2015 & %.3g & %.3g & %.3g  & %.3g  \\\\ \n', table4_lbl(i)+" &" ,tableD2(i,1), tableD2(i,2), tableD2(i,3), tableD2(i,4))
    end
    fprintf(fid,"Macro moments & & & \\\\ \n")
    fprintf(fid, '$\\quad$   %s 1985 & %.3g & %.3g & %.3g  & %.3g  \\\\ \n', table4_lbl(5)+" &" ,tableD2(5,1), tableD2(5,2), tableD2(5,3), tableD2(5,4))
    for i=6:9
        fprintf(fid, '$\\quad$   %s 1985-2015 & %.3g & %.3g & %.3g  & %.3g  \\\\ \n', table4_lbl(i)+" &" ,tableD2(i,1), tableD2(i,2), tableD2(i,3), tableD2(i,4))
    end
    fprintf(fid, '$\\quad$   %s 1985-2015 & %.3g & %.3g & %.3g  & %.3g  \\\\ \n', 'Change in return on capital &' ,tableD2(10,1), tableD2(10,2), tableD2(10,3), tableD2(10,4))
fclose(fid)


% Table D3 - model-implied regression coefficients
tableD3 = round([tableElasticAppendix(:,2)' ; 100*tableElasticAppendix(:,6)' ; tableElasticAppendix(:,7)'*100 ]',1);

fid = fopen('./Tables/TableDIII.tex','w')
    fprintf(fid,'Baseline & %8.1f & %8.1f & %.3g \\\\ \n', tableD3(1,:))
    fprintf(fid,'Low elasticity & %8.1f & %8.1f & %.3g \\\\ \n', tableD3(2,:))
    fprintf(fid,'Medium elasticity & %8.1f & %8.1f & %.3g \\\\ \n', tableD3(3,:))
    fprintf(fid,'High elasticity & %8.1f & %8.1f & %.3g \\\\ \n', tableD3(4,:))
    fprintf(fid,'Very high elasticity & %8.1f & %8.1f & %.3g \\\\ \n', tableD3(5,:))
fclose(fid)


 %% Generate figures %%
% MAKE SURE TO SET CURRENT DIRECTORY TO ../REPLICATION %

% Figure 5 - Returns and valuations (model experiment)
plot(tGrid-10,rGrid,'-','Color',blue_egb)
hold on
plot(tGrid-10,RGrid,':','Color',0.7*blue_egb + 0.3*[1 1 1])
hold on
plot(tGrid-10,mpkNetGrid-mpkNetGrid(1)+rGrid(1),'-.','Color',red_egb)
hold off
grid on
ylim([0.03 0.11])
yticks(0.03:0.02:0.11)
xticks(-10:10:50)
xlim([-5 45])
%ylabel('Returns')
%title('Returns')
xlabel('Years','Fontsize',20)
text(20,0.074,'Return on capital','Color',red_egb,'FontSize',18,'Rotation',0)
text(10,0.047,'Required return on wealth','Color',blue_egb,'FontSize',18,'Rotation',0)
text(1.5,0.097,'Realized return on wealth','Color',0.7*blue_egb + 0.3*[1 1 1],'FontSize',18,'Rotation',0)
saveas(gca,'./Figures\Figure5a','epsc');

plot(tGrid-10,aggQGrid/aggQGrid(1),'Color',blue_egb)
xticks(-10:10:40)
xlim([-5 45])
yticks(0.75:0.25:1.75)
ylim([0.75 1.75])
text(20,1.55,'Tobin''s Q','Color',blue_egb)
xlabel('Years','Fontsize',20)
grid on
saveas(gca,'./Figures\Figure5b','epsc');

% Figure 6 - Top wealth inequality (model experiment)
plot(tGrid-10,log(top0001./top0001(1)),':','Color',0.55*blue_egb + 0.45*[1 1 1])
hold on
plot(tGrid-10,log(top001./top001(1)),'-.','Color',0.70*blue_egb + 0.30*[1 1 1])
hold on
plot(tGrid-10,log(top01./top01(1)),'--','Color',0.85*blue_egb + 0.15*[1 1 1])
hold on
plot(tGrid-10,log(top1./top1(1)),'Color',blue_egb)
hold off
xticks(-10:10:50)
xlim([-5 45])
ylim([-0.4 1.2])
yticks(-0.4:0.4:1.2)
grid on
%ylabel('Top shares (log)')
%title('Top wealth shares (log)')
xlabel('Years','Fontsize',20)
legend('Top 0.001$\%$','Top 0.01$\%$','Top 0.1$\%$','Top 1$\%$','Location','Northwest')
saveas(gca,'./Figures\Figure6a','epsc');

plot(tGrid-10,log(thetaProxy001Grid/thetaProxy001Grid(1)),'Color',blue_egb)
hold on
plot(tGrid-10,(0.02*suffStat)*tGrid.^0,':','Color',0.5*[1 1 1])
hold off
xticks(-10:10:50)
xlim([-5 45])
yticks(-0.05:0.05:0.15)
ylim([-0.05 0.15])
grid on
%ylabel('Pareto inequality (log)')
xlabel('Years','Fontsize',20)
text(0,0.0125,'Model','Color',blue_egb)
text(0,0.11,'$-2\% \times$Sufficient Statistic','Color',0.5*[1 1 1])
saveas(gca,'./Figures\Figure6b','epsc');

% Figure 7 - Disentangling capital accumulation and revaluation (model experiment)
plot(tGrid-10,log(top01./top01(1)),'Color','Black')
hold on
plot(tGrid-10,log(top01shareBook/top01shareBook(1)),'-.','Color',red_egb)
hold on
plot(tGrid-10,log(top01./top01(1))-log(top01shareBook/top01shareBook(1)),':','Color',blue_egb)
hold off
xticks(-10:10:50)
xlim([-5 45])
ylim([-0.4 1.2])
yticks(-0.4:0.4:1.2)
grid on
ylabel('Top 0.1\% share growth (log)')
xlabel('Years','Fontsize',20)
text(22,0.63,'Total','Color','Black','FontSize',18,'Rotation',15)
text(22,0.45,'Capital accumulation','Color',red_egb,'FontSize',18,'Rotation',8)
text(22,0.15,'Revaluation','Color',blue_egb,'FontSize',18,'Rotation',5)
saveas(gca,'./Figures\Figure7a','epsc');

table_reval_alt = table_reval([1 2 3 4],[3 2]);
xlabelBar = categorical({'1\%','0.1\%','0.01\%','0.001\%'});
xlabelBar = reordercats(xlabelBar,{'1\%','0.1\%','0.01\%','0.001\%'});
hb=bar(xlabelBar,table_reval_alt,'stacked');
xlabel('Top groups','Fontsize',20)
hb(2).FaceColor = 0.6*red_egb+0.4*[1 1 1];
hb(1).FaceColor = blue_egb;
hb(1).LineWidth = 2;
hb(2).LineWidth = 2;
grid on
ylim([-0.5 1.5])
yticks(-0.5:0.5:1.5)
ylabel('Top share growth (log)')
text(2.5,1.15,'Capital accumulation','Color',0.8*red_egb+0.2*[1 1 1] )
text(2.5,-0.15,'Revaluation','Color', blue_egb )
saveas(gca,'./Figures\Figure7b','epsc');


% Figure 7 - Disentangling capital accumulation and revaluation (model experiment)
plot(tGrid-10,totalGrid,'Color','Black')
hold on
plot(tGrid-10,withinGrid,'Color',blue_egb)
hold on
plot(tGrid-10,betweenGrid,'Color',red_egb)
hold off
xticks(-10:10:50)
xlim([-5 45])
ylim([-0.06 0.06])
yticks([-0.06 -0.03 0 0.03 0.06])
grid on
%ylabel('Top 0.1\% share growth')
xlabel('Years','Fontsize',20)
text(3,0.02,'Total','Color','Black','FontSize',18,'Rotation',0)
text(3,0.05,'Intensive','Color',blue_egb,'FontSize',18,'Rotation',0)
text(3,-0.03,'Extensive','Color',red_egb,'FontSize',18,'Rotation',0)
saveas(gca,'./Figures\FigureD1','epsc');

