/***************************************************************************************************
Table I INDIVIDUALS IN THE TOP 100 (FORBES LIST, 2015)
***************************************************************************************************/

import delimited using "$MyPath/Data/forbes400_2015.csv", case(preserve) clear


tempname handle
file open `handle' using "$MyPath/Output/Numbers/stat_2015_entrepreneurs.tex", write replace
count if type == "entrepreneur"
file write `handle' "`=r(N)'"
file close `handle'

tempname handle
file open `handle' using "$MyPath/Output/Numbers/stat_2015_entrepreneurs_public.tex", write replace
count if type == "entrepreneur" & public == 1
file write `handle' "`=r(N)'"
file close `handle'

tempname handle
file open `handle' using "$MyPath/Output/Numbers/stat_2015_entrepreneurs_private.tex", write replace
count if type == "entrepreneur" & public == 0
file write `handle' "`=r(N)'"
file close `handle'

tempname handle
file open `handle' using "$MyPath/Output/Numbers/stat_2015_rentiers.tex", write replace
count if type == "rentier"
file write `handle' "`=r(N)'"
file close `handle'

tempname handle
file open `handle' using "$MyPath/Output/Numbers/stat_2015_financiers.tex", write replace
count if type == "financier"
file write `handle' "`=r(N)'"
file close `handle'





tempname handle
file open `handle' using "$MyPath/Output/Tables/TableI.tex", write replace
count if type == "entrepreneur"
file write `handle' "Entrepreneurs & `=r(N)' \\" _n
count if type == "entrepreneur" & public == 1
file write `handle' "\$\quad\$ Public corporations & `=r(N)' \\" _n
count if type == "entrepreneur" & public == 0
file write `handle' "\$\quad\$ Private corporations & `=r(N)' \\" _n
count if type == "rentier"
file write `handle' "Rentiers & `=r(N)' \\" _n
count if type == "financier"
file write `handle' "Financiers & `=r(N)' \\" _n
file close `handle'


/***************************************************************************************************
TABLE II SUMMARY STATISTICS
***************************************************************************************************/

import delimited using "$MyPath/save/forbes400_2015_financing", clear case(preserve)

tempname handle
file open `handle' using "$MyPath/Output/Numbers/stat_2015_lambdaM.tex", write replace
sum lambdaM
file write `handle' "`:di %3.2fc r(mean)'"
file close `handle'

tempname handle
file open `handle' using "$MyPath/Output/Numbers/stat_2015_epy_div.tex", write replace
sum epy_div
file write `handle' "`:di %3.1fc `= 100 * r(mean)''"
file close `handle'

tempname handle
file open `handle' using "$MyPath/Output/Numbers/stat_2015_epy_bb.tex", write replace
sum epy_bb
file write `handle' "`:di %3.1fc `= 100 * r(mean)''"
file close `handle'


file open `handle' using "$MyPath/Output/Numbers/stat_2015_epy.tex", write replace
sum epy
file write `handle' "`:di %3.1fc `= 100 *r(mean)''"
file close `handle'

file open `handle' using "$MyPath/Output/Numbers/stat_2015_speed.tex", write replace
sum speed
file write `handle' "`:di %3.0fc `= 100 *r(mean)''"
file close `handle'

tempname handle
file open `handle' using "$MyPath/Output/Numbers/stat_2015_logtheta.tex", write replace
sum suffstat
file write `handle' "`:di %3.1fc r(mean)'"
file close `handle'

tempname handle
file open `handle' using "$MyPath/output/Numbers/stat_2015_logtheta_equity.tex", write replace
sum suffstat_equity
file write `handle' "`:di %3.1fc r(mean)'"
file close `handle'

tempname handle
file open `handle' using "$MyPath/output/Numbers/stat_2015_logtheta_debt.tex", write replace
sum suffstat_debt
file write `handle' "`:di %3.1fc r(mean)'"
file close `handle'

tempname handle
file open `handle' using "$MyPath/Output/Numbers/stat_2015_abslogtheta.tex", write replace
sum suffstat
file write `handle' "`:di %3.1fc abs(r(mean))'"
file close `handle'


tempname handle
file open `handle' using "$MyPath/Output/Numbers/stat_logtheta_predictedchange.tex", write replace
sum suffstat
file write `handle' "`:di %3.1fc `= -2 * r(mean)''"
file close `handle'


tempfile postfile
tempname postname
postfile `postname' str60 varname obs mean min p25 p50 p75 max using `postfile'
label var epy "Equity payout yield"
label var epy_div "\quad Dividend yield"
label var epy_bb "\quad Buyback yield"
label var lambdaM "Market leverage"
label var speed "Growth rate of wealth"
foreach v of varlist epy epy_div epy_bb lambdaM speed {
    sum `v', d
    post `postname' (`"`:var label `v''"') (r(N)) (r(mean)) (r(min)) (r(p25)) (r(p50)) (r(p75)) (r(max))
}
postclose `postname'
use `postfile', clear
preserve
foreach v of varlist mean min p25 p50 p75 max{
    replace `v' = `v' * 100
    tostring `v', format(%4.1fc) replace force
    replace `v' = `v' + "\%"
}
listtab varname obs mean min p25 p50 p75 max using "$MyPath/Output/Tables/TableIIa.tex" if inrange(_n, 1 , 3), rstyle(tabular) replace

restore
format mean min p25 p50 p75 max %4.2fc
listtab varname obs mean min p25 p50 p75 max using "$MyPath/Output/Tables/TableIIb.tex" if _n > 3, rstyle(tabular) replace

/***************************************************************************************************
Table III ESTIMATED SUFFICIENT STATISTIC ∂r log θ
***************************************************************************************************/

cap program drop suffstat
program define suffstat, rclass
syntax anything(name=duration), speed(varname)
	tempvar temp
	gen `temp' = (1 + lambdaM * (epy * `duration' - 1)) 
	sum `temp'
	local numerator = r(mean)
	sum `speed'
	local denominator = r(mean)
	di `numerator' / `denominator'
	return scalar mystat = `numerator' / `denominator'
end


tempfile postfile
tempname postname
postfile `postname' str60 varname mean p5 p95 using `postfile'

import delimited using "$MyPath/save/forbes400_2015_financing.csv", clear case(preserve)

bootstrap r(mystat), reps(1000) seed(1): suffstat 35, speed(speed)
estat bootstrap, p
post `postname' ("Duration = 35 years (baseline)") (_b[_bs_1]) (e(ci_percentile)[1, 1]) (e(ci_percentile)[2, 1])

bootstrap r(mystat), reps(1000) seed(1): suffstat 20, speed(speed)
estat bootstrap, p
post `postname' ("Duration = 20 years") (_b[_bs_1]) (e(ci_percentile)[1, 1]) (e(ci_percentile)[2, 1])

bootstrap r(mystat), reps(1000) seed(1): suffstat 50, speed(speed)
estat bootstrap, p
post `postname' ("Duration = 50 years") (_b[_bs_1]) (e(ci_percentile)[1, 1]) (e(ci_percentile)[2, 1])

postclose `postname'
use `postfile', clear
format mean p5 p95 %3.1fc
listtab * using "$MyPath/Output/Tables/TableIIIa.tex" if _n == 1, rstyle(tabular) replace
listtab * using "$MyPath/Output/Tables/TableIIIb.tex" if inrange(_n, 2, 3), rstyle(tabular) replace

/***************************************************************************************************
Figure G1: Equity payout yield as a function of firm age
***************************************************************************************************/
import delimited using "$MyPath/Save/epy.csv", clear case(preserve)
twoway scatter epy age, mcolor("$blue") ///
xtitle("Firm age (years)", size(large)) ///
ytitle("Equity payout yield", size(large))  ///
xlabel(, labsize(medlarge) grid glcolor(gs14) glwidth(vthin)) /// 
ylabel(-0.1[0.05]0.1, labsize(medlarge)  grid angle(0)) ///
yline(0, lcolor("$red")) ///
graphregion(color(white))
graph export "$MyPath/Output/Figures/FigureC1.pdf", replace

/***************************************************************************************************
TABLE C.I SENSITIVITY ANALYSIS FOR ∂r log θ
***************************************************************************************************/

tempfile postfile
tempname postname
postfile `postname' str80 varname mean p5 p95 using `postfile'

import delimited using "$MyPath/save/forbes400_2015_financing.csv", clear case(preserve)
replace epy = epy - 0.005
bootstrap r(mystat), reps(1000) seed(1): suffstat 35, speed(speed)
estat bootstrap
post `postname' ("Equity payout yield \$- 0.5\text{pp}\$") (_b[_bs_1]) (e(ci_percentile)[1, 1]) (e(ci_percentile)[2, 1])

import delimited using "$MyPath/save/forbes400_2015_financing.csv", clear case(preserve)
replace epy = epy + 0.005
bootstrap r(mystat), reps(1000) seed(1): suffstat 35, speed(speed)
estat bootstrap
post `postname' ("Equity payout yield \$+ 0.5\text{pp}\$") (_b[_bs_1]) (e(ci_percentile)[1, 1]) (e(ci_percentile)[2, 1])

import delimited using "$MyPath/save/forbes400_2015_financing.csv", clear case(preserve)
replace lambdaM = lambdaM - 0.1
bootstrap r(mystat), reps(1000) seed(1): suffstat 35, speed(speed)
estat bootstrap
post `postname' ("Market leverage \$- 0.1\$") (_b[_bs_1]) (e(ci_percentile)[1, 1]) (e(ci_percentile)[2, 1])

import delimited using "$MyPath/save/forbes400_2015_financing.csv", clear case(preserve)
replace lambdaM = lambdaM + 0.1
bootstrap r(mystat), reps(1000) seed(1): suffstat 35, speed(speed)
estat bootstrap
post `postname' ("Market leverage \$+ 0.1\$") (_b[_bs_1]) (e(ci_percentile)[1, 1]) (e(ci_percentile)[2, 1])

import delimited using "$MyPath/save/forbes400_2015_financing", clear case(preserve)
replace speed = speed - 0.05
bootstrap r(mystat), reps(1000) seed(1): suffstat 35, speed(speed)
estat bootstrap
post `postname' ("Growth rate of wealth\$- 5\text{pp}$") (_b[_bs_1]) (e(ci_percentile)[1, 1]) (e(ci_percentile)[2, 1])

import delimited using "$MyPath/save/forbes400_2015_financing", clear case(preserve)
replace speed = speed + 0.05
bootstrap r(mystat), reps(1000) seed(1): suffstat 35, speed(speed)
estat bootstrap
post `postname' ("Growth rate of wealth\$+ 5\text{pp}\$") (_b[_bs_1]) (e(ci_percentile)[1, 1]) (e(ci_percentile)[2, 1])

import delimited using "$MyPath/save/forbes400_2015_financing", clear case(preserve)
gen speed_low = log(networth / 5) / (2015 - foundingoracq_year)
bootstrap r(mystat), reps(1000) seed(1): suffstat 35, speed(speed_low)
estat bootstrap
post `postname' ("Growth rate of wealth assuming initial wealth \$W_{t_0} = 10\$") (_b[_bs_1]) (e(ci_percentile)[1, 1]) (e(ci_percentile)[2, 1])

import delimited using "$MyPath/save/forbes400_2015_financing", clear case(preserve)
gen speed_high = log(networth / 0.2) / (2015 - foundingoracq_year)
bootstrap r(mystat), reps(1000) seed(1): suffstat 35, speed(speed_high)
estat bootstrap
post `postname' ("Growth rate of wealth assuming initial wealth \$W_{t_0} = 0.1\$") (_b[_bs_1]) (e(ci_percentile)[1, 1]) (e(ci_percentile)[2, 1])

postclose `postname'
use `postfile', clear
format mean p5 p95 %3.1fc
listtab * using "$MyPath/Output/Tables/TableCIa.tex" if inrange(_n, 1, 2), rstyle(tabular) replace
listtab * using "$MyPath/Output/Tables/TableCIb.tex" if inrange(_n, 3, 4), rstyle(tabular) replace
listtab * using "$MyPath/Output/Tables/TableCIc.tex" if inrange(_n, 5, 6), rstyle(tabular) replace
listtab * using "$MyPath/Output/Tables/TableCId.tex" if inrange(_n, 7, 8), rstyle(tabular) replace


/***************************************************************************************************
Table C.II ESTIMATES FOR ∂r log θALT
***************************************************************************************************/

import delimited using "$MyPath/save/forbes400_2015_financing", clear case(preserve)

gen suffstat_alt = (1 + lambdaM * (epy * 35 - 1)) / speed

gen speed_low = log(networth / 5) / (2015 - foundingoracq_year)
gen suffstat_alt_low = (1 + lambdaM * (epy * 20 - 1)) / speed_low

gen speed_high = log(networth / 0.2) / (2015 - foundingoracq_year)
gen suffstat_alt_high = (1 + lambdaM * (epy * 50 - 1)) / speed_high

tempfile postfile
tempname postname
postfile `postname' str60 varname mean p5 p95 using `postfile'

bootstrap r(mean), reps(1000) seed(1): sum suffstat_alt
estat bootstrap
post `postname' ("Duration = 35 years (baseline)") (_b[_bs_1]) (e(ci_percentile)[1, 1]) (e(ci_percentile)[2, 1])

bootstrap r(mean), reps(1000) seed(1): sum suffstat_alt_low
estat bootstrap
post `postname' ("Duration = 20 years") (_b[_bs_1]) (e(ci_percentile)[1, 1]) (e(ci_percentile)[2, 1])

bootstrap r(mean), reps(1000) seed(1): sum suffstat_alt_high
estat bootstrap
post `postname' ("Duration = 50 years") (_b[_bs_1]) (e(ci_percentile)[1, 1]) (e(ci_percentile)[2, 1])

postclose `postname'
use `postfile', clear
format mean p5 p95 %3.1fc
listtab * using "$MyPath/Output/Tables/TableCIIa.tex" if _n == 1, rstyle(tabular) replace
listtab * using "$MyPath/Output/Tables/TableCIIb.tex" if inrange(_n, 2, 3), rstyle(tabular) replace



/***************************************************************************************************
Supplementary Material TABLE E.I INDIVIDUALS IN THE TOP 100 IN 1985 (FORBES LIST)
***************************************************************************************************/

import delimited using "$MyPath/Data/forbes400_1985.csv", case(preserve) clear

tempname handle
file open `handle' using "$MyPath/Output/Numbers/stat_1985_entrepreneurs.tex", write replace
count if type == "entrepreneur"
file write `handle' "`=r(N)'"
file close `handle'

tempname handle
file open `handle' using "$MyPath/Output/Numbers/stat_1985_entrepreneurs_public.tex", write replace
count if type == "entrepreneur" & public == 1
file write `handle' "`=r(N)'"
file close `handle'

tempname handle
file open `handle' using "$MyPath/Output/Numbers/stat_1985_entrepreneurs_private.tex", write replace
count if type == "entrepreneur" & public == 0
file write `handle' "`=r(N)'"
file close `handle'

tempname handle
file open `handle' using "$MyPath/Output/Numbers/stat_1985_rentiers.tex", write replace
count if type == "rentier"
file write `handle' "`=r(N)'"
file close `handle'

tempname handle
file open `handle' using "$MyPath/Output/Numbers/stat_1985_financiers.tex", write replace
count if type == "financier"
file write `handle' "`=r(N)'"
file close `handle'



tempname handle
file open `handle' using "$MyPath/Output/Tables/TableEI.tex", write replace
count if type == "entrepreneur"
file write `handle' "Entrepreneurs & `=r(N)' \\" _n
count if type == "entrepreneur" & public == 1
file write `handle' "\$\quad\$ Public corporations & `=r(N)' \\" _n
count if type == "entrepreneur" & public == 0
file write `handle' "\$\quad\$ Private corporations & `=r(N)' \\" _n
count if type == "rentier"
file write `handle' "Rentiers & `=r(N)' \\" _n
count if type == "financier"
file write `handle' "Financiers & `=r(N)' \\" _n
file close `handle'

/***************************************************************************************************
Supplementary Material TABLE E.II SUMMARY STATISTICS IN 1985
***************************************************************************************************/

import delimited using "$MyPath/save/forbes400_1985_financing", clear case(preserve)

tempname handle
file open `handle' using "$MyPath/output/Numbers/stat_1985_lambdaM.tex", write replace
sum lambdaM
file write `handle' "`:di %3.2fc r(mean)'"
file close `handle'

tempname handle
file open `handle' using "$MyPath/output/Numbers/stat_1985_epy_div.tex", write replace
sum epy_div
file write `handle' "`:di %3.1fc `= 100 * r(mean)''"
file close `handle'

tempname handle
file open `handle' using "$MyPath/output/Numbers/stat_1985_epy_bb.tex", write replace
sum epy_bb
file write `handle' "`:di %3.1fc `= 100 * r(mean)''"
file close `handle'

tempname handle
file open `handle' using "$MyPath/output/Numbers/stat_1985_epy.tex", write replace
sum epy
file write `handle' "`:di %3.1fc `= 100 *r(mean)''"
file close `handle'

tempname handle
file open `handle' using "$MyPath/output/Numbers/stat_1985_logtheta.tex", write replace
sum suffstat
file write `handle' "`:di %3.1fc r(mean)'"
file close `handle'

tempfile postfile
tempname postname
postfile `postname' str60 varname obs mean min p25 p50 p75 max using `postfile'
label var epy "Equity payout yield"
label var epy_div "\quad Dividend yield"
label var epy_bb "\quad Buyback yield"
label var lambdaM "Market leverage"
label var speed "Growth rate of wealth"
foreach v of varlist epy epy_div epy_bb lambdaM speed {
	sum `v', d
	post `postname' (`"`:var label `v''"') (r(N))  (r(mean)) (r(min)) (r(p25)) (r(p50)) (r(p75)) (r(max))
}
postclose `postname'

use `postfile', clear
foreach v of varlist mean min p25 p50 p75 max{
	replace `v' = `v' * 100
	tostring `v', format(%4.1fc) replace force
	replace `v' = `v' + "\%"
}
listtab varname obs mean min p25 p50 p75 max using  "$MyPath/output/tables/TableEIIa.tex" if inrange(_n, 1 , 3), rstyle(tabular) replace

use `postfile', clear
format  mean min p25 p50 p75 max %4.2fc
listtab varname obs mean min p25 p50 p75 max using  "$MyPath/output/tables/TableEIIb.tex" if _n > 3, rstyle(tabular) replace

/***************************************************************************************************
Supplementary Material TABLE E.III ESTIMATED SUFFICIENT STATISTIC AT THE SECOND-ORDER
***************************************************************************************************/
import delimited using "$MyPath/save/forbes400_2015_financing", clear  case(preserve)
sum speed
gen suffstat_heterogeneous = (1 + lambdaM * (epy * (35 + 35^2 * 0.01) - 1)) / r(mean)
collapse (mean) suffstat suffstat_*
gen year = 2015
tempfile temp
save `temp'

import delimited using "$MyPath/save/forbes400_1985_financing", clear case(preserve)
sum speed
gen suffstat_heterogeneous = (1 + lambdaM * (epy * (35 - 35^2 * 0.01) - 1)) / r(mean)
collapse (mean) suffstat suffstat_*
gen year = 1985
append using `temp'


sort year
tempname handle
file open `handle' using "$MyPath/Output/Numbers/stat_logtheta_secondorder_homogeneous.tex", write replace
file write `handle' "`:di %3.1fc (suffstat[1]+ suffstat[2])/2'"
file close `handle'


sort year
tempname handle
file open `handle' using "$MyPath/Output/Numbers/stat_logtheta_secondorder_heterogeneous.tex", write replace
file write `handle' "`:di %3.1fc (suffstat_heterogeneous[1]+ suffstat_heterogeneous[2])/2'"
file close `handle'

tempfile postfile
tempname postname
postfile `postname' str100 varname suffstat_1985 suffstat_2015 suffstat_average using `postfile'
label var suffstat "Constant duration (35 years in 1985 and in 2015)"
label var suffstat_heterogeneous "Increasing duration (23 years in 1985 and 47 years in 2015)"
foreach v of varlist suffstat suffstat_heterogeneous{
	sum `v', d
	post `postname' (`"`:var label `v''"') (`=`v'[1]') (`=`v'[2]') (`=(`v'[1] + `v'[2])/2')
}
postclose `postname'

use `postfile', clear
format suffstat_1985 suffstat_2015 suffstat_average %4.1fc
listtab varname suffstat_1985 suffstat_2015 suffstat_average using "$MyPath/Output/Tables/TableEIII.tex", rstyle(tabular) replace
