/***************************************************************************************************
Create average wealth per household over time
***************************************************************************************************/
* needed because BOGZ1FL192090005A only starts in 1980
import delimited using "$MyPath/Data/FRED/TNWBSHNO.csv", clear case(preserve)
gen year = year(date(date, "YMD"))
bys year: keep if _n == _N
keep year TNWBSHNO
replace TNWBSHNO = TNWBSHNO * 1e9
tempfile temp0
save `temp0'

import delimited using "$MyPath/Data/FRED/BOGZ1FL192090005A.csv", clear case(preserve)
gen year = year(date(date, "YMD"))
bys year: keep if _n == _N
keep year BOGZ1FL192090005A
* it's in millions
replace BOGZ1FL192090005A = BOGZ1FL192090005A * 1e6
tempfile temp1
save `temp1'

import delimited using "$MyPath/Data/FRED/TTLHH.csv", clear case(preserve)
gen year = year(date(date, "YMD"))
replace TTLHH = TTLHH * 1e3
bys year: keep if _n == _N
keep year TTLHH

merge 1:1 year using `temp0', nogen
merge 1:1 year using `temp1', nogen
keep if year >= 1950
gen wealthpc = BOGZ1FL192090005A / TTLHH
gen wealth2pc = TNWBSHNO / TTLHH
keep year wealth*
save "$MyPath/save/wealthpc", replace

/***************************************************************************************************
Construct dividend yield, buyback yield, and market leverage in years in which firms are private using Compustat
***************************************************************************************************/
* get universe of gvkey we will use
import delimited using "$MyPath/Data/forbes400_2015.csv", clear
keep gvkey
tempfile temp
save `temp'

import delimited using "$MyPath/Data/forbes400_1985.csv", clear
keep gvkey
append using `temp'
duplicates drop gvkey, force
save `temp', replace

/* clean compustat */
import delimited using "$MyPath/Data/funda.csv", clear
gen date = date(datadate, "YMD")
format date %td
* usual filters
keep if consol == "C"
keep if indfmt == "INDL"
keep if datafmt == "STD"
keep if popsrc == "D"
gen year = year(date)
replace year = year - 1 if month(date) <= 5
bys gvkey year (date): keep if _n == _N
rename conm firmname
destring gvkey, replace
sort gvkey

* restrict to the set of firms owned by individuals in Forbes
merge m:1 gvkey using `temp',  keep(matched) nogen

* Generate dividend yield
tsset gvkey year
gen me = mkvalt
replace me = prcc_f * csho if missing(me)
replace me = . if me < 0
gen epy_div = dv / ((me + L.me) / 2)
winsor2 epy_div, cuts(1 99) replace

* Generate buyback yield
tsset gvkey year
replace aqc = 0 if missing(aqc)
replace aqc = 0 if year == 1997 & regexm(firmname, "APPLE")
replace sppe = 0 if missing(sppe)
gen epy_bb =  - log((csho * adjex_f)/ (L.csho * L.adjex_f)) + (aqc - sppe) / ((me + L.me) / 2)
winsor2 epy_bb, cuts(1 99) replace

* generate market leverage
replace che = 0 if missing(che)
gen lambdaM = (me + at - seq - che) / me
winsor2 lambdaM, cuts(1 99) replace
tsset gvkey year
order gvkey year firmname epy*   lambdaM
keep gvkey year firmname epy*  lambdaM
save "$MyPath/save/issuance_compustat", replace

/***************************************************************************************************
Construct equity payout yield, market leverage, and growth rate for individuals in Forbes top 100 in 2015
***************************************************************************************************/
import delimited using "$MyPath/Data/forbes400_2015.csv", case(preserve) clear
keep if !missing(gvkey)
gen period = 2022 - foundingoracq_year
expand period
bys name: gen year = 2022 - _N + _n
merge m:1 gvkey year using "$MyPath/save/issuance_compustat", keep(master matched) nogen

* Set lambdaM of public firms pre-IPO to lambdaM post IPO
gen myear = - year
bys name (myear): replace lambdaM = lambdaM[_n-1] if missing(lambdaM)
drop myear
keep if year <= 2015

* Set dividend yield of public firms pre-IPO to zero
replace epy_div = 0 if missing(epy_div)

* Set buyback yield of public firms post IPO as log of ownwership share divided by age
replace epy_bb = log(secform_ownership) / (secform_year - foundingoracq_year) if year <= secform_year & secform_year > foundingoracq_year

gen age = year - foundingoracq_year
gen epy = epy_div + epy_bb
binscatter epy age, n(20)  savedata("$MyPath/Save/epy") replace
collapse (mean) epy_bb epy_div lambdaM, by(name rank)
tempfile temp_compustat
save `temp_compustat'


import delimited using "$MyPath/Data/forbes400_2015.csv", case(preserve) clear
drop if inlist(type, "financier", "rentier")
merge 1:1 rank using `temp_compustat', nogen

* Take care of Koum (Whatspp, which is never public but available dilution rate)
replace epy_bb = log(secform_ownership) / (secform_year - foundingoracq_year) if regexm(name, "Koum")
replace epy_div = 0 if regexm(name, "Koum, Jan")
replace lambdaM = 1 if regexm(name, "Koum, Jan")

assert !missing(epy_bb) if public == 1
assert !missing(epy_div) if public == 1
assert !missing(lambdaM) if public == 1
* set dividend and buyback yield of private firms to zero
replace epy_bb = 0 if public == 0
replace epy_div = 0 if public == 0
sum lambdaM if public == 1
replace lambdaM = r(mean) if public == 0

* Generate equity payout yield
gen epy = epy_div + epy_bb

* Generate growth rate of wealth
preserve
use "$MyPath/save/wealthpc", clear
sum wealthpc if year == 2015
local wealthpc = r(mean)
restore
replace networth = networth * 1e6 / `wealthpc'
gen speed = log(networth) / (2015 - foundingoracq_year)

* Generate sufficient statistic
sum speed 
gen suffstat = (1 + lambdaM * (epy * 35 - 1)) / r(mean)
gen suffstat_debt = (1 - lambdaM) / r(mean)
gen suffstat_equity = lambdaM * epy * 35 / r(mean)
outsheet using "$MyPath/save/forbes400_2015_financing.csv", comma replace


/***************************************************************************************************
Construct equity payout yield, market leverage, and growth rate for individuals in Forbes top 100 in 2015
***************************************************************************************************/
import delimited using "$MyPath/Data/forbes400_1985.csv", case(preserve) clear
keep if !missing(gvkey)
gen period = 2022 - foundingoracq_year
expand period
bys name: gen year = 2022 - _N + _n
merge m:1 gvkey year using "$MyPath/save/issuance_compustat", keep(master matched) nogen

* Set lambdaM of public firms pre-IPO to lambdaM post IPO
gen myear = - year
bys name (myear): replace lambdaM = lambdaM[_n-1] if missing(lambdaM)
drop myear
keep if year <= 1985

* Set dividend yield of public firms pre-IPO to zero
replace epy_div = 0 if missing(epy_div)

* Set buyback yield of public firms post IPO as log of ownwership share divided by age
replace epy_bb = log(secform_ownership) / (secform_year - foundingoracq_year) if year <= secform_year & secform_year > foundingoracq_year
collapse (mean) epy_bb epy_div lambdaM, by(name rank)
tempfile temp_compustat
save `temp_compustat'


import delimited using "$MyPath/Data/forbes400_1985.csv", case(preserve) clear
drop if inlist(type, "financier", "rentier")
merge 1:1 rank using `temp_compustat', nogen
assert !missing(epy_bb) if public == 1
assert !missing(epy_div) if public == 1
assert !missing(lambdaM) if public == 1

* set dividend and buyback yield of private firms to zero
replace epy_bb = 0 if public == 0
replace epy_div = 0 if public == 0
sum lambdaM if public == 1
replace lambdaM = r(mean) if public == 0

* Generate equity payout yield
gen epy = epy_div + epy_bb

* Generate growth rate of wealth
preserve
use "$MyPath/save/wealthpc", clear
sum wealth2pc if year == 1985
local wealth2pc = r(mean)
restore
gen speed = log(networth * 1e6 / `wealth2pc') / (1985 - foundingoracq_year)

* Generate sufficient statistic
sum speed
gen suffstat = (1 + lambdaM * (epy * 35 - 1)) / r(mean)
gen suffstat_debt = (1 - lambdaM) / r(mean)
gen suffstat_equity = lambdaM * epy * 35 / r(mean)
outsheet using "$MyPath/save/forbes400_1985_financing.csv", comma replace

