/***************************************************************************************************
Plot rise in top wealth inequality ***************************************************************************************************/

* Data from SZZ
import delimited using "$MyPath/Data/wealth_szz_baseline_estimates.csv", case(lower) clear
keep if inrange(year, 1985, 2015)
gen theta_top1 = 1 + log(top01 / top1) / log(10)
gen theta_top01 = 1 + log(top001 / top01) / log(10)
gen theta_top001 = 1 + log(top0001 / top001) / log(10)
keep year top* theta_top*
tempfile temp_SZZ
save `temp_SZZ'

* Data from Forbes
import delimited using "$MyPath/Data/forbes400_panel.csv", clear case(preserve)
gen logrank = log(rank - 1/2)
gen lognetworth = log(networth)
statsby, by(year) clear: reg lognetworth logrank
gen theta_rank = -_b_logrank
tempfile temp_forbes
save `temp_forbes'

import delimited using "$MyPath/Data/forbes400_panel.csv", clear case(preserve)
collapse (mean) mean = networth (min) min= networth, by(year)
gen theta_meanmin = 1 - min / mean

merge 1:1 year using `temp_forbes', nogen
merge 1:1 year using `temp_SZZ', nogen

foreach v of varlist top* theta_* {
	sum `v' if year == 1985
	gen log`v'_norm = log(`v' / r(mean))
}

/* Figure 4 - Rise in top wealth inequality (1985-2015) a) */
twoway (line logtop1_norm year if inrange(year,1985,2015), lwidth(thick) color("$blue%100")) ///
(line logtop01_norm year if inrange(year,1985,2015), lwidth(thick) lpattern("longdash") color("$blue%85")) ///
(line logtop001_norm year if inrange(year,1985,2015), lwidth(thick) lpattern("dash") color("$blue%70")) ///
(line logtop0001_norm year if inrange(year,1985,2015), lwidth(thick) lpattern("shortdash") color("$blue%55")), ///
xlabel(1985[10]2015, labsize(large) grid glcolor(gs14) glwidth(vthin)) graphregion(color(white)) ///
ylabel(, labsize(large)  grid angle(0)) ///
ytitle("", size(large))  xtitle("", size(large)) ///
legend(order(1 "Top 1%" 2 "Top 0.1%" 3 "Top 0.01%" 4 "Top 0.001%") size(medsmall) rows(2) symysize(6) symxsize(6) region(lwidth(vvthin)))
graph export "$MyPath/Output/Figures/Figure4a.pdf", replace

/* Figure 4 - Rise in top wealth inequality (1985-2015) b) */
twoway (line logtheta_top01_norm year if inrange(year,1985,2015), lwidth(thick) color("$blue%85")) ///
(line logtheta_top001_norm year if inrange(year,1985,2015), lwidth(thick) lpattern("longdash") color("$blue%55")) ///
(line logtheta_meanmin_norm year if inrange(year,1985,2015), lwidth(thick) lpattern("dash") color("$red%85")) ///
(line logtheta_rank_norm year if inrange(year,1985,2015), lwidth(thick) lpattern("shortdash") color("$red%55")), ///
xlabel(1985[10]2015, labsize(large) grid glcolor(gs14) glwidth(vthin)) graphregion(color(white)) ///
ylabel(0 0.15 0.3 0.45, labsize(large)  grid angle(0)) ///
ytitle("", size(large))  xtitle("", size(large)) ///
legend(order(1 "Ratio top shares (p=0.01%)" 2 "Ratio top shares (p=0.001%)" 3 "Mean-min (Forbes 400)" 4 "log-rank (Forbes 400) " )  size(medsmall) rows(2) symysize(6) symxsize(6) region(lwidth(vvthin)))
graph export "$MyPath/Output/Figures/Figure4b.pdf", replace

/* TABLE C.V ESTIMATES OF PARETO INEQUALITY */
tempfile postfile
tempname postname
postfile `postname' str80 varname pre mean post using `postfile'
label var theta_top1 "Ratio top shares (1\%-0.1\%)"
label var theta_top01 "Ratio top shares (0.1\%-0.01\%)"
label var theta_top001 "Ratio top shares (0.01\%-0.001\%)"
label var theta_meanmin "Mean-min (Forbes 400)"
label var theta_rank "Log-rank (Forbes 400)"
foreach v of varlist theta_top1 theta_top01 theta_top001 theta_meanmin theta_rank  {
	qui sum `v' if inrange(year, 1980, 1985)
	local m_pre = r(mean)
	qui sum `v' if inrange(year, 1980, 2020)
	local m = r(mean)
	qui sum `v' if inrange(year, 2015, 2020)
	local m_post = r(mean)
	post `postname' (`"`:var label `v''"') (`m_pre') (`m') (`m_post')
}
postclose `postname'
use `postfile', clear
format pre mean post %4.2fc
listtab varname pre mean post using  "$MyPath/Output/Tables/TableCV.tex", rstyle(tabular) replace 

/* Output statistics */
gen v = log(post / pre)
sum v
tempname handle
file open `handle' using "$MyPath/Output/Numbers/stat_logtheta_change.tex", write replace
file write `handle' "`:di %4.0fc 100 * r(mean)'"
file close `handle'
